/// Class which can be used for the HttpClient setup. It currently is used
/// for calculation of request size as some default headers are not predictable
/// in our calculation.
class DynatraceHttpClientOptions {
  /// Headers which will be attached to a request but are not visible at the time of sending the request
  final Map<String, String> requestHeaders;

  /// Those are the headers which are added by default when using HttpClient of dart
  static const Map<String, String> _defaultHeaders = {
    "Accept-Encoding": "gzip",
    "User-Agent": "Dart/X.X (dart:io)"
  };

  /// Constructor which allows to specify custom default headers. Should also be used if default
  /// user-agent is changed or accept-encoding header is deactivated.
  DynatraceHttpClientOptions(this.requestHeaders);

  /// Standard constructor which will set default headers as we expect them from Flutter.
  const DynatraceHttpClientOptions.standard()
      : requestHeaders = _defaultHeaders;

  /// Returning the used default headers in case a the list of headers is expanded.
  static Map<String, String> getDefaultHeaders() {
    return _defaultHeaders;
  }
}
