import 'dart:io';

/// Helper class which converts an int statusCode to string
class HttpStatusCodeConverter {
  /// Map of all Http Status codes
  static const Map<int, String> _httpStatusCodes = {
    HttpStatus.continue_: 'Continue',
    HttpStatus.switchingProtocols: 'Switching Protocols',
    HttpStatus.processing: 'Processing',
    HttpStatus.ok: 'OK',
    HttpStatus.created: 'Created',
    HttpStatus.accepted: 'Accepted',
    HttpStatus.nonAuthoritativeInformation: 'Non-Authoritative Information',
    HttpStatus.noContent: 'No Content',
    HttpStatus.resetContent: 'Reset Content',
    HttpStatus.partialContent: 'Partial Content',
    HttpStatus.multiStatus: 'Multi-Status',
    HttpStatus.multipleChoices: 'Multiple Choices',
    HttpStatus.movedPermanently: 'Moved Permanently',
    HttpStatus.movedTemporarily: 'Moved Temporarily',
    HttpStatus.seeOther: 'See Other',
    HttpStatus.notModified: 'Not Modified',
    HttpStatus.useProxy: 'Use Proxy',
    HttpStatus.temporaryRedirect: 'Temporary Redirect',
    HttpStatus.permanentRedirect: 'Permanent Redirect',
    HttpStatus.badRequest: 'Bad Request',
    HttpStatus.unauthorized: 'Unauthorized',
    HttpStatus.paymentRequired: 'Payment Required',
    HttpStatus.forbidden: 'Forbidden',
    HttpStatus.notFound: 'Not Found',
    HttpStatus.methodNotAllowed: 'Method Not Allowed',
    HttpStatus.notAcceptable: 'Not Acceptable',
    HttpStatus.proxyAuthenticationRequired: 'Proxy Authentication Required',
    HttpStatus.requestTimeout: 'Request Timeout',
    HttpStatus.conflict: 'Conflict',
    HttpStatus.gone: 'Gone',
    HttpStatus.lengthRequired: 'Length Required',
    HttpStatus.preconditionFailed: 'Precondition Failed',
    HttpStatus.requestUriTooLong: 'Request-URI Too Long',
    HttpStatus.unsupportedMediaType: 'Unsupported Media Type',
    HttpStatus.requestedRangeNotSatisfiable: 'Requested Range Not Satisfiable',
    HttpStatus.expectationFailed: 'Expectation Failed',

    /// Any attempt to brew coffee with a teapot should result in
    /// the error code "418 I'm a teapot".
    ///
    /// The resulting entity body MAY be short and stout.
    ///
    /// https://tools.ietf.org/html/rfc2324#section-2.3.2
    ///
    418: 'I\'m a Teapot',
    HttpStatus.insufficientStorage: 'Insufficient Space on Resource',

    /// A deprecated response used by the Spring Framework when a method has failed.
    ///
    /// https://tools.ietf.org/rfcdiff?difftype=--hwdiff&url2=draft-ietf-webdav-protocol-06.txt
    ///
    420: 'Method Failure',
    HttpStatus.unprocessableEntity: 'Unprocessable Entity',
    HttpStatus.locked: 'Locked',
    HttpStatus.failedDependency: 'Failed Dependency',
    HttpStatus.preconditionRequired: 'Precondition Required',
    HttpStatus.tooManyRequests: 'Too Many Requests',
    HttpStatus.requestHeaderFieldsTooLarge: 'Request Header Fields Too Large',
    HttpStatus.unavailableForLegalReasons: 'Unavailable For Legal Reasons',
    HttpStatus.internalServerError: 'Internal Server Error',
    HttpStatus.notImplemented: 'Not Implemented',
    HttpStatus.badGateway: 'Bad Gateway',
    HttpStatus.serviceUnavailable: 'Service Unavailable',
    HttpStatus.gatewayTimeout: 'Gateway Timeout',
    HttpStatus.httpVersionNotSupported: 'HTTP Version Not Supported',
  };

  /// Resolves [statusCode] to the string equivalent which is used in the response message
  static String getStatusMessage(int statusCode) {
    if (_httpStatusCodes.containsKey(statusCode)) {
      return _httpStatusCodes[statusCode]!;
    }

    return '';
  }
}
